#!/bin/bash

######################
# BigLinux Iso Generator
# by Bruno Gonçalves Araujo <bigbruno@gmail.com>
# licensed under GPLv2 or greater.
# released in 07/10/2015


# Forma de uso
# $1 pasta de trabalho
# $2 tipo de compactacao xz ou gzip
# $3 nome de identificacao do iso
# Exemplo: sudo /usr/share/biglinux/iso-generator/makesquashfs.sh "/home/bruno/remaster/iso32bits" "gzip" "BigLinux 14.04 final"


cd "$1"

# Kernel e initrd para o livecd
mkdir -p image/casper
rm -f remaster/chroot/boot/*old-dkms*

# fix keyboard

echo '# KEYBOARD CONFIGURATION FILE

# Consult the keyboard(5) manual page.

XKBMODEL="pc105"
XKBLAYOUT="us"
XKBVARIANT=""
XKBOPTIONS=""

BACKSPACE="guess"' > remaster/chroot/etc/default/keyboard

# fix chromium icon
cp -f remaster/chroot/usr/share/icons/hicolor/48x48/apps/chromium-browser.png remaster/chroot/usr/share/icons/hicolor/32x32/apps/chromium-browser.png
rm -f remaster/chroot/etc/hostname

# fix ping
chmod 4755 remaster/chroot/bin/ping


# Corrige erros no boot
sed -i 's|.*crash.init||g' remaster/chroot//usr/share/initramfs-tools/scripts/casper 

cp -f $(find remaster/chroot/boot/ -name vmlinuz*generic* |  tail -1) image/casper/vmlinuz
cp -f $(find remaster/chroot/boot/ -name initrd.img*generic* |  tail -1) image/casper/initrd.lz

cp -f $(find remaster/chroot/boot/ -name vmlinuz*xanmod* |  tail -1) image/casper/vmlinuz-xanmod
cp -f $(find remaster/chroot/boot/ -name initrd.img*xanmod* |  tail -1) image/casper/initrd-xanmod.lz

# Gera o manifest
chroot remaster/chroot dpkg-query -W --showformat='${Package} ${Version}\n' | sudo tee image/casper/filesystem.manifest
cp -v image/casper/filesystem.manifest image/casper/filesystem.manifest-desktop
REMOVE='ubiquity biglinux-install-desktop-icon ubiquity-frontend-gtk ubiquity-frontend-kde live lupin-live live-initramfs deepin-installer'



live-boot live-config live-config-systemd

for i in $REMOVE 
do
        sed -i "/${i}/d" image/casper/filesystem.manifest-desktop
done

/usr/share/biglinux/iso-generator/chroot-off.sh "$1" 2> /dev/null
/usr/share/biglinux/iso-generator/chroot-off.sh "$1" 2> /dev/null
/usr/share/biglinux/iso-generator/chroot-off.sh "$1" 2> /dev/null

# Gera o squashfs
#gzip
if [ "$2" = "gzip" ]; then
    rm -f remaster/chroot/apt_errors*.txt
    rm -f image/casper/filesystem.squashfs
    mksquashfs remaster/chroot image/casper/filesystem.squashfs -comp zstd -Xcompression-level 6 -no-xattrs
fi


#xz
if [ "$2" = "xz" ]; then
    rm -f remaster/chroot/apt_errors*.txt
    rm -f image/casper/filesystem.squashfs
    mksquashfs remaster/chroot image/casper/filesystem.squashfs -comp zstd -Xcompression-level 15 -no-xattrs
fi


printf $(du -sx --block-size=1 remaster/chroot | cut -f1) > image/casper/filesystem.size


touch image/ubuntu
mkdir image/.disk
cd image/.disk
touch base_installable
echo "full_cd/single" > cd_type
echo "$3" > info
echo "Remaster generated by BigLinux Iso Generator - https://www.biglinux.com.br" > release_notes_url
cd ../../
